
package com.ebaiyihui.family.doctor.server.common.enums;

/**
 * @Author:yanliang
 * @Date:2019/6/12 16:00
 * @Description 在线咨询订单状态枚举
 *
 */
public enum AdmissionStatusEnum {


    /**
     * 已取消：用户未支付
     */
    CANCEL("已取消", 0,"患者未支付订单"),
    /**
     * 待接待：请尽快与处理咨询
     */
    TO_BE_RECEIVED("待接诊", 1,"医生未接诊"),
    /**
     * 咨询中：距离咨询结束还有[25:00]小时
     */
    IN_CONSULTATION("进行中", 2,"就诊正在进行中"),
    /**
     * 已退款（拒绝）：您已拒绝申请
     */
    REFUNDED_REFUSE("已退款", 4,"已退款，医生拒绝接诊"),
    /**
     * 已退款（超时）：有效期内未处理咨询已退款`
     */
    NOT_RECEIVED_TIME_OUT("已退款", 5,"已退款，医生超时未接诊"),
    /**
     * 已退款（申请）：您申请的退款已处理成功
     */
    REFUNDED_APPLY("已退款", 6,"已退款，医生主动取消"),
    /**
     * 已结束（主动）：您主动结束了咨询
     */
    FINISH_APPLY("已完成", 7,"已结束就诊，患者未评价"),
    /**
     * 已结束（超时）：咨询超时结束
     */
    FINISH_TIME_OUT("已完成", 8,"已结束就诊，患者未评价"),

    /**
     * 已结束（已评价）
     */
    FINISH_APPLY_REVIEWED("已完成", 9,"已结束就诊，患者已评价"),

    /**
     * 已退号（已退款）
     */
    RETIRED("已退款", 111,"已退款，等待问诊患者主动取消"),

    /**
     * 待接诊医生停诊
     */
    DOCTOR_CLOSED_SCHEDULE("已退款", 112,"已退款，医生停诊"),
    /**
     * 待候诊医生停诊
     */
    DOCTOR_CLOSED_WATING_SCHEDULE("已退款", 113,"已退款，医生停诊"),

    /**
     * 状态 : 0 元已拒绝
     * 订单已完成
     * 就诊 咨询超时/主动结束
     */
    REFUNDED_REFUSE_ZERO("已拒绝", 30,"医生超时未接诊"),


    WAIT_ADMISSION("待问诊",20,"等待到达预约问诊时间"),

    EXPIRED("已过期",10,"已退款，患者超时未进入问诊"),

    TO_BE_RECEIVED_REFUND("已退款",15,"已退款，等待接诊患者主动取消"),

    REFERRAL("已完成",40,"已转诊，医生已转诊"),
    REFERRAL_MANAGER("已完成",41,"已转诊，管理员转诊"),
    PASSNUMBER("已过号",50,"患者已过号"),
    PASSNUMBER_REFUND_ZERO("已退款",114,"患者过号"),
    PASSNUMBER_REFUND("已退款",115,"已退款，患者过号"),

    /**
     * 已退款，管理员取消
     */
    ADMIN_REFUNDED("已失效", 45, "已退款，管理员取消"),
    /**
     * 已退款，管理员取消(待候诊）
     */
    ADMIN_REFUNDED_ADMISSION("已失效", 46, "已退款，管理员取消"),

    /**
     * 旧转诊单状态
     */
    REFERRAL_MANAGER_FINISH("已完成",42,"医生已转诊"),


    /**
     * 管理端审核
     */
    OFFICE_REVIEW("退款审核中", 98, "退款审核中"),

    /**
     *互联网办公室审核通过
     */


    INTERNET_OFFICE_REVIEW("退款审核中",99,"退款审核中");

    private String desc;
    private Integer value;
    private String display;
    /**
     * @param desc
     */
    private AdmissionStatusEnum(String desc, Integer value, String display) {
        this.desc = desc;
        this.value = value;
        this.display = display;
    }


    public String getDesc() {
        return desc;
    }


    public void setDesc(String desc) {
        this.desc = desc;
    }


    public Integer getValue() {
        return value;
    }


    public void setValue(Integer value) {
        this.value = value;
    }
    public String getDisplay(){
        return display;
    }
    public void setDisplay(String display){
        this.display=display;
    }

    public static String getDesc(Integer value) {
        if (value == null || value < 0) {
            return null;
        }
        for (AdmissionStatusEnum admissionStatusEnum : AdmissionStatusEnum.values()) {
            if (value.equals(admissionStatusEnum.getValue())) {
                return admissionStatusEnum.getDesc();
            }
        }
        return null;
    }
    public static String getDisplay(Integer value) {
        if (value == null || value < 0) {
            return null;
        }
        for (AdmissionStatusEnum admissionStatusEnum : AdmissionStatusEnum.values()) {
            if (value.equals(admissionStatusEnum.getValue())) {
                return admissionStatusEnum.getDisplay();
            }
        }
        return null;
    }

    public static AdmissionStatusEnum getEnum(Integer value) {
        if (value == null || value < 0) {
            return null;
        }
        for (AdmissionStatusEnum admissionStatusEnum : AdmissionStatusEnum.values()) {
            if (value.equals(admissionStatusEnum.getValue())) {
                return admissionStatusEnum;
            }
        }
        return null;
    }
}
