package com.ebaiyihui.family.doctor.server.service.impl;

import com.alibaba.fastjson.JSON;
import com.doctoruser.api.pojo.base.dto.doctor.QueryPersonnelInfoReq;
import com.doctoruser.api.pojo.base.vo.doctor.PersonnelInfo;
import com.ebaiyihui.family.doctor.common.dto.*;
import com.ebaiyihui.family.doctor.common.vo.*;
import com.ebaiyihui.family.doctor.server.common.constants.IMInformConstants;
import com.ebaiyihui.family.doctor.server.common.constants.ProjProperties;
import com.ebaiyihui.family.doctor.server.entity.PatientEntity;
import com.ebaiyihui.family.doctor.server.entity.PatientSignEntity;
import com.ebaiyihui.family.doctor.server.feign.DoctorInfofeignClient;
import com.ebaiyihui.family.doctor.server.feign.IMSyncMsgClient;
import com.ebaiyihui.family.doctor.server.mapper.PatientMapper;
import com.ebaiyihui.family.doctor.server.mapper.PatientSignMapper;
import com.ebaiyihui.family.doctor.server.service.OrderManagementService;
import com.ebaiyihui.family.doctor.server.util.IDCardUtil;
import com.ebaiyihui.family.doctor.server.util.PageUtil;
import com.ebaiyihui.framework.response.BaseResponse;
import com.ebaiyihui.framework.utils.HttpKit;
import com.ebaiyihui.imforward.client.vo.IMQueryMsgReqVO;
import com.ebaiyihui.imforward.client.vo.IMSingleMsgResultVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

@Service
@Slf4j
public class OrderManagementServiceImpl implements OrderManagementService {

    @Autowired
    private PatientSignMapper patientSignMapper;

    @Autowired
    private PatientMapper patientMapper;

    @Autowired
    private ProjProperties projProperties;

    @Autowired
    private DoctorInfofeignClient doctorInfofeignClient;

    @Autowired
    private IMSyncMsgClient imSyncMsgClient;

    @Override
    public BaseResponse<PageUtil<OrderListResVo>> orderList(OrderListReqDTO param) {
        log.info("查询订单列表入参：{}", JSON.toJSONString(param));

        param.setPageNum((param.getPageNum() - 1) * param.getPageSize());
        List<OrderListResVo> records = patientSignMapper.orderList(param);
        PageUtil<OrderListResVo> pageUtil = new PageUtil<>();
        pageUtil.setList(records);
        QueryOrderTotalVo totalVo = patientSignMapper.countSumOrder(param);
        pageUtil.setObject(totalVo);
        return BaseResponse.success(pageUtil);
    }

    @Override
    public BaseResponse<OrderDetailsResVo> getOrderDetails(OrderDetailResDTO param) {
        log.info("查询订单详情入参：{}", JSON.toJSONString(param));
        OrderDetailsResVo resVo = new OrderDetailsResVo();
        String orderId = param.getOrderId();
        PatientSignEntity patientSignEntity = patientSignMapper.selectById(orderId);
        if (Objects.isNull(patientSignEntity)) {
            return BaseResponse.error("订单不存在");
        }
        // 处方信息
        resVo.setPresListResVOS(getPresList(patientSignEntity.getAdmId()));
        // 订单信息
        resVo.setOrderInfo(buildOrderInfo(patientSignEntity));
        // 沟通记录
        resVo.setImSingleMsgResultVOS(queryImMsg(patientSignEntity));

        return BaseResponse.success(resVo);
    }

    /**
     * 获取聊天记录
     */
    private List<IMSingleMsgResultVO> queryImMsg(PatientSignEntity patientSignEntity){
        List<IMSingleMsgResultVO> imSingleMsgResultVOS = new ArrayList<>();
        IMQueryMsgReqVO reqVO = new IMQueryMsgReqVO();
        List<String> admIdList = new ArrayList<>();
        admIdList.add(patientSignEntity.getAdmId());
        reqVO.setAppointmentId(admIdList);
        reqVO.setBusinessCode("jtys");
        reqVO.setPage(0);
        reqVO.setPageSize(9999);
        reqVO.setMsgType("1");
        reqVO.setUserId(patientSignEntity.getPatientUserId());

        BaseResponse<List<IMSingleMsgResultVO>> listBaseResponse = imSyncMsgClient.queryImMsg(reqVO);
        List<IMSingleMsgResultVO> imSingleMsgResultVoS = listBaseResponse.getData();
        if (null != imSingleMsgResultVoS) {
            Iterator<IMSingleMsgResultVO> it = imSingleMsgResultVoS.iterator();
            while (it.hasNext()) {
                IMSingleMsgResultVO x = it.next();
                if ("administrator".equals(x.getSender())) {
                    it.remove();
                } else if (x.getSender().contains(IMInformConstants.PATIENT_APPLICATION_CODE)) {
                    x.setSender(IMInformConstants.PATIENT_APPLICATION_CODE);
                } else if (x.getSender().contains(IMInformConstants.DOCTOR_APPLICATION_CODE)) {
                    x.setSender(IMInformConstants.DOCTOR_APPLICATION_CODE);
                }
            }
            imSingleMsgResultVOS = imSingleMsgResultVoS.stream().sorted(Comparator.comparing(IMSingleMsgResultVO::getSendTime)).collect(Collectors.toList());
        }
        return imSingleMsgResultVOS;
    }


    /**
     * 构建订单基础信息
     */
    private OrderInfo buildOrderInfo(PatientSignEntity patientSignEntity) {
        log.info("buildOrderInfo：{}", JSON.toJSONString(patientSignEntity));
        // 获取患者详情信息
        PatientEntity patient = patientMapper.selectById(patientSignEntity.getPatientId());
        log.info("patient：{}", JSON.toJSONString(patient));
        // 获取医生基本信息
        QueryPersonnelInfoReq queryPersonnelInfoReq = new QueryPersonnelInfoReq();
        queryPersonnelInfoReq.setDoctorId(String.valueOf(patientSignEntity.getDoctorId()));
        BaseResponse<PersonnelInfo> doctorInfo = doctorInfofeignClient.queryPersonnelInfo(queryPersonnelInfoReq);
        if (null == doctorInfo && !doctorInfo.isSuccess()) {
            log.error("IM INFORM ERROR : 获取医生信息失败 doctorId：{}", String.valueOf(patientSignEntity.getDoctorId()));
        }
        log.info("doctorInfo：{}", JSON.toJSONString(doctorInfo));

        OrderInfo orderInfo = new OrderInfo();
        orderInfo.setOrderNo(patientSignEntity.getId());
        orderInfo.setPatientPhone(patientSignEntity.getPatientPhone());
        orderInfo.setPatientSex(patient.getGender());
        orderInfo.setPatientName(patient.getPatientName());
        orderInfo.setPatientAge(IDCardUtil.getAge(patient.getCredNo()));
        orderInfo.setDoctorPhone(doctorInfo.getData().getPhoneNum());
        orderInfo.setDoctorName(patientSignEntity.getDoctorName());
        orderInfo.setDoctorTitle(doctorInfo.getData().getTitle());
        orderInfo.setHospital(patientSignEntity.getOrganName());
        orderInfo.setFirstDepartment(patientSignEntity.getDeptName());
        log.info("orderInfo：{}", JSON.toJSONString(orderInfo));
        return orderInfo;
    }

    /**
     * 获取处方信息
     */
    private List<GetPresListResVO> getPresList(String admId) {
        GetPresListReqVO reqVo = new GetPresListReqVO();
        reqVo.setAdmId(admId);
        try {
            log.info("查询处方列表URL:{},入参{}, ", projProperties.getPresListByAdmId(), JSON.toJSONString(reqVo));
            String body = HttpKit.jsonPost(projProperties.getPresListByAdmId(), JSON.toJSONString(reqVo));
            BaseResponse<GetPresListResVO> baseResponse = JSON.parseObject(body, BaseResponse.class);
            log.info("baseResponse:{} ",baseResponse);
            if (baseResponse.getData() == null) {
                return null;
            }
            List<GetPresListResVO> resVOList = (List<GetPresListResVO>) baseResponse.getData();
            log.info("查询处方列表返回值:{} ",resVOList);
            return resVOList;
        } catch (Exception e) {
            log.error("查询处方列表调用失败{}", e.getMessage());
        }
        return null;
    }
}
